Re: [PATCH 2/2] mm: memory-failure: kill __soft_offline_page()

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 




On 2022/8/30 15:15, HORIGUCHI NAOYA(堀口 直也) wrote:
On Fri, Aug 19, 2022 at 11:34:02AM +0800, Kefeng Wang wrote:
Squash the __soft_offline_page() into soft_offline_in_use_page() and
kill __soft_offline_page().

Signed-off-by: Kefeng Wang <wangkefeng.wang@xxxxxxxxxx>
---
  mm/memory-failure.c | 24 +++++++++---------------
  1 file changed, 9 insertions(+), 15 deletions(-)

diff --git a/mm/memory-failure.c b/mm/memory-failure.c
index 1a7d6548ccb2..5b368124956d 100644
--- a/mm/memory-failure.c
+++ b/mm/memory-failure.c
@@ -2432,11 +2432,11 @@ static bool isolate_page(struct page *page, struct list_head *pagelist)
  }
/*
  * __soft_offline_page handles hugetlb-pages and non-hugetlb pages.
   * If the page is a non-dirty unmapped page-cache page, it simply invalidates.
   * If the page is mapped, it migrates the contents over.
   */
-static int __soft_offline_page(struct page *page)
+static int soft_offline_in_use_page(struct page *page)
  {
  	long ret = 0;
  	unsigned long pfn = page_to_pfn(page);
@@ -2449,6 +2449,13 @@ static int __soft_offline_page(struct page *page)
  		.gfp_mask = GFP_USER | __GFP_MOVABLE | __GFP_RETRY_MAYFAIL,
  	};
+ if (!huge && PageTransHuge(hpage)) {
+		if (try_to_split_thp_page(page)) {
+			pr_info("soft offline: %#lx: thp split failed\n", pfn);
+			return -EBUSY;
+		}
I've found that this change causes a regression. After the thp is
successfully split here, hpage no longer points to a proper page.
So hpage should be updated to point to the raw error page.

+		hpage = page;
@@ -2432,11 +2432,11 @@ static bool isolate_page(struct page *page, struct list_head *pagelist)
  }
/*
- * __soft_offline_page handles hugetlb-pages and non-hugetlb pages.
+ * soft_offline_in_use_page handles hugetlb-pages and non-hugetlb pages.
   * If the page is a non-dirty unmapped page-cache page, it simply invalidates.
   * If the page is mapped, it migrates the contents over.
Sorry for the regression,  will update.

Could you update the patch?

Thanks,
Naoya Horiguchi




[Index of Archives]     [Linux ARM Kernel]     [Linux ARM]     [Linux Omap]     [Fedora ARM]     [IETF Annouce]     [Bugtraq]     [Linux OMAP]     [Linux MIPS]     [eCos]     [Asterisk Internet PBX]     [Linux API]

  Powered by Linux